@@ -1,5 +1,5 @@
 from PyQt5 import QtCore
-from PyQt5.QtCore import Qt, QPointF
+from PyQt5.QtCore import Qt, QPointF, QPoint
 from PyQt5.QtGui import QBrush, QColor, QPixmap
 from PyQt5.QtWidgets import QGraphicsView, QFrame, QGraphicsScene, QGraphicsItem
 from typing import Optional, List
@@ -217,4 +217,4 @@ class ExtendedScene(QGraphicsView):
         factor_y = y / self._background.pixmap().height()
         factor = max(min(factor_x, factor_y), self.minimum_scale)
         self.zoom(factor, QPoint(0, 0))
-        self._scale *= factor
\ No newline at end of file
+        self._scale *= factor
